/* -------------------------------------------------------------------------- */
/*                                   Imports                                  */
/* -------------------------------------------------------------------------- */
import React from "react";
import classNames from "classnames";
import '../index.css'
/* -------------------------------------------------------------------------- */
/*                               Component props                              */
/* -------------------------------------------------------------------------- */
type Props = {
    emphasis?: 'high' | 'medium' | 'low' | undefined,
    disabled?:boolean,
    iconed?: boolean,
} & Omit<React.ComponentPropsWithoutRef<"button">, "">


/* -------------------------------------------------------------------------- */
/*                          Component implementation                          */
/* -------------------------------------------------------------------------- */
export const Button = ({
    emphasis ='high',
    disabled = false,
    iconed = false,
    className,
    children, ...props} : Props) => {

    return(
        <button
        //TODO change on click event
        onClick={!disabled ? () => alert('Click') : undefined}
        
        className={classNames([
            'text-center',
            'px-4 py-2 text-[15px]',
            'rounded',
            {
                '!cursor-default': disabled, 
                'transition-all': !disabled,
                'transition duration-200':!disabled,
                
            },
            {
                // Define high emphasis
                'text-white': emphasis === 'high',
                'text-gray-300': disabled && emphasis !='high',
                'bg-blue-500': !disabled && emphasis ==='high',
                'hover:bg-blue-400': !disabled && emphasis ==='high',                
                'active:bg-blue-700': !disabled && emphasis ==='high',
                'bg-gray-200': disabled && emphasis ==='high',
                'focus:outline outline-blue-500/60 outline-5':!disabled && emphasis === 'high',
                'focus:shadow-lg shadow-blue-500':!disabled && emphasis === 'high',
                
                //Define medium emphasis
                'text-blue-500': !disabled && emphasis === 'medium',
                'hover:text-blue-400': !disabled && emphasis === 'medium' || emphasis === 'low',
                'active:text-blue-600': !disabled && emphasis === 'medium',
                'bg-white': emphasis === 'medium',
                'focus:outline outline-blue-400/10 outline-8':!disabled && emphasis === 'medium' || emphasis === 'high',
                //Border
                'border': emphasis === 'medium',
                'border-gray-200' : disabled && emphasis === 'medium',
                'border-gray-500': !disabled && emphasis === 'medium',
                'hover:border-blue-400':!disabled && emphasis === 'medium',
                'active:border-blue-600': !disabled && emphasis === 'medium',
                'focus:border-blue-600/70':!disabled && emphasis === 'medium',

                //define low emphasis 
                'text-gray-900': !disabled && emphasis === 'low',
                'active:text-blue-700': !disabled && emphasis === 'low',
                'bg-transparent': emphasis ==='low',           
                'focus:bg-gray-100': emphasis === 'low',  
                'focus:outline-none': emphasis === 'low',
            },
            className,
        ])} 
        {...props}>
            {children}
        </button>
    );
}

